@@ -16,7 +16,7 @@ Readonly::Hash our %ENTITIES => (
 );
 Readonly::Scalar our $ENTITIES => join q{}, keys %ENTITIES;
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 # Decode chars.
 sub decode {
@@ -205,7 +205,7 @@ Install the PYX modules.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/PYX-Utils>
+L<https://github.com/michal-josef-spacek/PYX-Utils>
 
 =head1 AUTHOR
 
@@ -219,6 +219,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
